export class PDFSinglePageViewer extends PDFViewer {
    set scrollMode(mode: any);
    _updateScrollMode(): void;
    set spreadMode(mode: any);
    _updateSpreadMode(): void;
}
import { PDFViewer } from "./pdf_viewer.js";
